itkwasm.environment_dispatch - itkwasm python documentation
Description: Module Contents: Classes:,, FunctionFactory,,,,, Functions:,, environment_dispatch,,,,, Data:,, function_factory,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.environment_dispatch`

## Module Contents

### Classes

`FunctionFactory` |

### Functions

`environment_dispatch` |

### Data

`function_factory` |

### API

class itkwasm.environment_dispatch.FunctionFactory

  Initialization

  register(interface_package: str, func_name: str, func: Callable, priority: int = 1) → None
  lookup(interface_package: str, func_name: str) → Optional[Set[Callable]]
  highest_priority(interface_package: str, func_name: str) → Optional[Callable]

    Highest priority registered function with priority > 0.

  set_priority(func: Callable, priority: int) → None
  get_priority(func: Callable) → int
  disable(interface_package: str, func_name: str)

    Set the priorites of all registered functions to -1.

itkwasm.environment_dispatch.function_factory

  None

itkwasm.environment_dispatch.environment_dispatch(interface_package: str, func_name: str) → Callable